'use strict';

var ramda = require('ramda');
var _toConsumableArray = require('@babel/runtime/helpers/toConsumableArray');

function _reduce(handleIndex) {
  return ramda.reduce(function (acc, p) {
    var n = Number(p);

    // key is string
    if (Number.isNaN(n)) {
      return [].concat(_toConsumableArray(acc), [p]);
    }
    return handleIndex(acc, n);
  }, []);
}
function parse(path) {
  if (!ramda.is(String, path)) {
    throw new Error('Given value is must be string!');
  }
  return ramda.compose(_reduce(function (acc, n) {
    if (n < 0) {
      throw new Error('Negative index is found!');
    }
    return [].concat(_toConsumableArray(acc), [n]);
  }), ramda.split('.'))(path);
}
parse.ignore = function ignore(path) {
  return ramda.compose(_reduce(function (acc, n) {
    return n > -1 ? [].concat(_toConsumableArray(acc), [n]) : acc;
  }), ramda.split('.'))(path);
};
parse.unsafe = function unsafe(path) {
  return ramda.compose(_reduce(function (acc, n) {
    return [].concat(_toConsumableArray(acc), [n > -1 ? n : 0]);
  }), ramda.split('.'))(path);
};
parse.abs = function abs(path) {
  return ramda.compose(_reduce(function (acc, n) {
    return [].concat(_toConsumableArray(acc), [Math.abs(n)]);
  }), ramda.split('.'))(path);
};

function get(path, o) {
  var lens;
  if (ramda.is(String, path)) {
    lens = ramda.compose(ramda.lensPath, parse)(path);
  } else if (ramda.is(Array, path)) {
    lens = ramda.lensPath(path);
  }
  return ramda.view(lens, o);
}
var get$1 = ramda.curry(get);

function set(path, v, o) {
  var lens;
  if (ramda.is(String, path)) {
    lens = ramda.compose(ramda.lensPath, parse)(path);
  } else if (ramda.is(Array, path)) {
    lens = ramda.lensPath(path);
  }
  return ramda.set(lens, v, o);
}
var set$1 = ramda.curry(set);

exports.get = get$1;
exports.parse = parse;
exports.set = set$1;
//# sourceMappingURL=index.js.map
