import { is, compose, split, reduce, curry, lensPath, view, set as set$2 } from 'ramda';
import _toConsumableArray from '@babel/runtime/helpers/toConsumableArray';

function _reduce(handleIndex) {
  return reduce(function (acc, p) {
    var n = Number(p);

    // key is string
    if (Number.isNaN(n)) {
      return [].concat(_toConsumableArray(acc), [p]);
    }
    return handleIndex(acc, n);
  }, []);
}
function parse(path) {
  if (!is(String, path)) {
    throw new Error('Given value is must be string!');
  }
  return compose(_reduce(function (acc, n) {
    if (n < 0) {
      throw new Error('Negative index is found!');
    }
    return [].concat(_toConsumableArray(acc), [n]);
  }), split('.'))(path);
}
parse.ignore = function ignore(path) {
  return compose(_reduce(function (acc, n) {
    return n > -1 ? [].concat(_toConsumableArray(acc), [n]) : acc;
  }), split('.'))(path);
};
parse.unsafe = function unsafe(path) {
  return compose(_reduce(function (acc, n) {
    return [].concat(_toConsumableArray(acc), [n > -1 ? n : 0]);
  }), split('.'))(path);
};
parse.abs = function abs(path) {
  return compose(_reduce(function (acc, n) {
    return [].concat(_toConsumableArray(acc), [Math.abs(n)]);
  }), split('.'))(path);
};

function get(path, o) {
  var lens;
  if (is(String, path)) {
    lens = compose(lensPath, parse)(path);
  } else if (is(Array, path)) {
    lens = lensPath(path);
  }
  return view(lens, o);
}
var get$1 = curry(get);

function set(path, v, o) {
  var lens;
  if (is(String, path)) {
    lens = compose(lensPath, parse)(path);
  } else if (is(Array, path)) {
    lens = lensPath(path);
  }
  return set$2(lens, v, o);
}
var set$1 = curry(set);

export { get$1 as get, parse, set$1 as set };
//# sourceMappingURL=index.js.map
